# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/cognito.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.cognito import access_key_pb2 as eolymp_dot_cognito_dot_access__key__pb2
from eolymp.cognito import quota_pb2 as eolymp_dot_cognito_dot_quota__pb2
from eolymp.cognito import user_pb2 as eolymp_dot_cognito_dot_user__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/cognito/cognito.proto\x12\x0e\x65olymp.cognito\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/cognito/access_key.proto\x1a\x1a\x65olymp/cognito/quota.proto\x1a\x19\x65olymp/cognito/user.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcc\x02\n\x10\x43reateTokenInput\x12>\n\ngrant_type\x18\x01 \x01(\x0e\x32*.eolymp.cognito.CreateTokenInput.GrantType\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12\x15\n\rcode_verifier\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x15\n\rrefresh_token\x18\t \x01(\t\"_\n\tGrantType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\x12\x16\n\x12\x41UTHORIZATION_CODE\x10\x02\x12\x11\n\rREFRESH_TOKEN\x10\x03\x12\x0f\n\x0bGOOGLE_CODE\x10\x04\"\xaa\x01\n\x11\x43reateTokenOutput\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12.\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06scopes\x18\x04 \x03(\t\x12\x15\n\rrefresh_token\x18\n \x01(\t\x12\x0f\n\x07user_id\x18\x64 \x01(\t\x12\x10\n\x08username\x18\x65 \x01(\t\"%\n\x14IntrospectTokenInput\x12\r\n\x05token\x18\x01 \x01(\t\"\xfd\x01\n\x15IntrospectTokenOutput\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\r\n\x05scope\x18\x02 \x01(\t\x12*\n\x06\x65xpire\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x10\n\x08\x61udience\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x64 \x01(\t\x12\x10\n\x08nickname\x18\x65 \x01(\t\x12\x0f\n\x07picture\x18\x66 \x01(\t\x12\r\n\x05\x65mail\x18g \x01(\t\x12\x16\n\x0e\x65mail_verified\x18h \x01(\x08\x12\x0e\n\x06locale\x18i \x01(\t\"\xaf\x01\n\x18\x43reateAuthorizationInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63ode_challenge\x18\x02 \x01(\t\x12\x1d\n\x15\x63ode_challenge_method\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x15\n\rresponse_type\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\"M\n\x19\x43reateAuthorizationOutput\x12\x1a\n\x12\x61uthorization_code\x18\x01 \x01(\t\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\"\x16\n\x14IntrospectQuotaInput\"\xe9\x01\n\x15IntrospectQuotaOutput\x12\x30\n\x11\x63ontests_per_user\x18\n \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x33\n\x14problems_per_contest\x18\x0b \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x37\n\x18participants_per_contest\x18\x0c \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x30\n\x11problems_per_user\x18\x14 \x01(\x0b\x32\x15.eolymp.cognito.Quota\"\x15\n\x13IntrospectUserInput\":\n\x14IntrospectUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"$\n\x11\x44\x65scribeUserInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"8\n\x12\x44\x65scribeUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"\xd2\x01\n\x0eListUsersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.cognito.ListUsersInput.Filter\x1aj\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\x08username\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"E\n\x0fListUsersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.cognito.User\"\x9b\x01\n\x0f\x43reateUserInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x10\n\x08\x62irthday\x18\x06 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\n \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"D\n\x10\x43reateUserOutput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x02 \x01(\t\"\xac\x01\n\x0fNotifyUserInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08template\x18\x02 \x01(\t\x12\x43\n\nparameters\x18\x03 \x03(\x0b\x32/.eolymp.cognito.NotifyUserInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x10NotifyUserOutput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"3\n\x10VerifyEmailInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x13\n\x11VerifyEmailOutput\"!\n\x10UpdateEmailInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"4\n\x11UpdateEmailOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x02 \x01(\t\"\xdc\x02\n\x12UpdateProfileInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.cognito.UpdateProfileInput.Patch\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07\x63ompany\x18\x0c \x01(\t\x12\x12\n\noccupation\x18\r \x01(\t\x12\x0f\n\x07\x63ountry\x18\x15 \x01(\t\x12\x0c\n\x04\x63ity\x18\x16 \x01(\t\x12\x10\n\x08\x62irthday\x18! \x01(\t\x12\x0e\n\x06locale\x18\" \x01(\t\"x\n\x05Patch\x12\x0c\n\x08USERNAME\x10\x00\x12\t\n\x05\x45MAIL\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0b\n\x07\x43OMPANY\x10\x03\x12\x0e\n\nOCCUPATION\x10\x04\x12\x0b\n\x07\x43OUNTRY\x10\x05\x12\x08\n\x04\x43ITY\x10\x06\x12\x0c\n\x08\x42IRTHDAY\x10\x07\x12\n\n\x06LOCALE\x10\x08\"6\n\x13UpdateProfileOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x01 \x01(\t\"f\n\x12UpdatePictureInput\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08offset_x\x18\n \x01(\r\x12\x10\n\x08offset_y\x18\x0b \x01(\r\x12\x0c\n\x04size\x18\x0c \x01(\r\"\x15\n\x13UpdatePictureOutput\"E\n\x13UpdatePasswordInput\x12\x18\n\x10\x63urrent_password\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"\x16\n\x14UpdatePasswordOutput\"\x1e\n\x1cResendEmailVerificationInput\"@\n\x1dResendEmailVerificationOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x01 \x01(\t\"D\n\x12StartRecoveryInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"2\n\x13StartRecoveryOutput\x12\x1b\n\x13\x65mail_recovery_hint\x18\x01 \x01(\t\"I\n\x14\x43ompleteRecoverInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\x17\n\x15\x43ompleteRecoverOutput\"\x16\n\x14IntrospectRolesInput\"&\n\x15IntrospectRolesOutput\x12\r\n\x05roles\x18\x01 \x03(\t\"!\n\x0eListRolesInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\" \n\x0fListRolesOutput\x12\r\n\x05roles\x18\x01 \x03(\t\"2\n\x10UpdateRolesInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"\x13\n\x11UpdateRolesOutput\"\x13\n\x11SelfDestructInput\"C\n\x12SelfDestructOutput\x12-\n\tdelete_on\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"!\n\x10RevokeTokenInput\x12\r\n\x05token\x18\x01 \x01(\t\"\x13\n\x11RevokeTokenOutput\"1\n\x0bSigninInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"2\n\x0cSigninOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"\"\n\x0cSignoutInput\x12\x12\n\neverywhere\x18\x01 \x01(\x08\"\x0f\n\rSignoutOutput\"G\n\x14\x43reateAccessKeyInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05scope\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\"7\n\x15\x43reateAccessKeyOutput\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"&\n\x14\x44\x65leteAccessKeyInput\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteAccessKeyOutput\"3\n\x13ListAccessKeysInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"O\n\x14ListAccessKeysOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.cognito.AccessKey2\xbf\x19\n\x07\x43ognito\x12\x64\n\x0b\x43reateToken\x12 .eolymp.cognito.CreateTokenInput\x1a!.eolymp.cognito.CreateTokenOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12o\n\x0fIntrospectToken\x12$.eolymp.cognito.IntrospectTokenInput\x1a%.eolymp.cognito.IntrospectTokenOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x12\x63\n\x0bRevokeToken\x12 .eolymp.cognito.RevokeTokenInput\x1a!.eolymp.cognito.RevokeTokenOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x12l\n\x07Signout\x12\x1c.eolymp.cognito.SignoutInput\x1a\x1d.eolymp.cognito.SignoutOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0f\"\r/self/signout\x12\xa3\x01\n\x0f\x43reateAccessKey\x12$.eolymp.cognito.CreateAccessKeyInput\x1a%.eolymp.cognito.CreateAccessKeyOutput\"C\x82\xe3\n\x1c\x8a\xe3\n\x18\x63ognito:access-key:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0e\"\x0c/access-keys\x12\xac\x01\n\x0f\x44\x65leteAccessKey\x12$.eolymp.cognito.DeleteAccessKeyInput\x1a%.eolymp.cognito.DeleteAccessKeyOutput\"L\x82\xe3\n\x1c\x8a\xe3\n\x18\x63ognito:access-key:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17*\x15/access-keys/{key_id}\x12\x9f\x01\n\x0eListAccessKeys\x12#.eolymp.cognito.ListAccessKeysInput\x1a$.eolymp.cognito.ListAccessKeysOutput\"B\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ognito:access-key:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/access-keys\x12n\n\nCreateUser\x12\x1f.eolymp.cognito.CreateUserInput\x1a .eolymp.cognito.CreateUserOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x08\"\x06/users\x12\x82\x01\n\x0bVerifyEmail\x12 .eolymp.cognito.VerifyEmailInput\x1a!.eolymp.cognito.VerifyEmailOutput\".\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02\x19\"\x17/users/{user_id}/verify\x12\xae\x01\n\x17ResendEmailVerification\x12,.eolymp.cognito.ResendEmailVerificationInput\x1a-.eolymp.cognito.ResendEmailVerificationOutput\"6\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!\"\x1f/self/email/resend-verification\x12v\n\x0bUpdateEmail\x12 .eolymp.cognito.UpdateEmailInput\x1a!.eolymp.cognito.UpdateEmailOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02\r\"\x0b/self/email\x12v\n\rUpdateProfile\x12\".eolymp.cognito.UpdateProfileInput\x1a#.eolymp.cognito.UpdateProfileOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/self\x12~\n\rUpdatePicture\x12\".eolymp.cognito.UpdatePictureInput\x1a#.eolymp.cognito.UpdatePictureOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0f\"\r/self/picture\x12\x98\x01\n\x0eUpdatePassword\x12#.eolymp.cognito.UpdatePasswordInput\x1a$.eolymp.cognito.UpdatePasswordOutput\";\x82\xe3\n\x12\x8a\xe3\n\x0epassword_grant\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/password\x12y\n\x0eIntrospectUser\x12#.eolymp.cognito.IntrospectUserInput\x1a$.eolymp.cognito.IntrospectUserOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x07\x12\x05/self\x12\x98\x01\n\x0c\x44\x65scribeUser\x12!.eolymp.cognito.DescribeUserInput\x1a\".eolymp.cognito.DescribeUserOutput\"A\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HC\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x12\x12\x10/users/{user_id}\x12\x84\x01\n\tListUsers\x12\x1e.eolymp.cognito.ListUsersInput\x1a\x1f.eolymp.cognito.ListUsersOutput\"6\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00pA\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/users\x12\x82\x01\n\x0fIntrospectQuota\x12$.eolymp.cognito.IntrospectQuotaInput\x1a%.eolymp.cognito.IntrospectQuotaOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/self/quota\x12\x82\x01\n\x0fIntrospectRoles\x12$.eolymp.cognito.IntrospectRolesInput\x1a%.eolymp.cognito.IntrospectRolesOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/self/roles\x12\x94\x01\n\tListRoles\x12\x1e.eolymp.cognito.ListRolesInput\x1a\x1f.eolymp.cognito.ListRolesOutput\"F\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:role:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\x12\x16/users/{user_id}/roles\x12\x9a\x01\n\x0bUpdateRoles\x12 .eolymp.cognito.UpdateRolesInput\x1a!.eolymp.cognito.UpdateRolesOutput\"F\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:role:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\x1a\x16/users/{user_id}/roles\x12\x7f\n\rStartRecovery\x12\".eolymp.cognito.StartRecoveryInput\x1a#.eolymp.cognito.StartRecoveryOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/recovery\x12\x90\x01\n\x10\x43ompleteRecovery\x12$.eolymp.cognito.CompleteRecoverInput\x1a%.eolymp.cognito.CompleteRecoverOutput\"/\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1a\"\x18/users/{user_id}/recover\x12s\n\x0cSelfDestruct\x12!.eolymp.cognito.SelfDestructInput\x1a\".eolymp.cognito.SelfDestructOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x07*\x05/selfB1Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.cognito_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _NOTIFYUSERINPUT_PARAMETERSENTRY._options = None
  _NOTIFYUSERINPUT_PARAMETERSENTRY._serialized_options = b'8\001'
  _COGNITO.methods_by_name['CreateToken']._options = None
  _COGNITO.methods_by_name['CreateToken']._serialized_options = b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002'
  _COGNITO.methods_by_name['IntrospectToken']._options = None
  _COGNITO.methods_by_name['IntrospectToken']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2'
  _COGNITO.methods_by_name['RevokeToken']._options = None
  _COGNITO.methods_by_name['RevokeToken']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n'
  _COGNITO.methods_by_name['Signout']._options = None
  _COGNITO.methods_by_name['Signout']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\017\"\r/self/signout'
  _COGNITO.methods_by_name['CreateAccessKey']._options = None
  _COGNITO.methods_by_name['CreateAccessKey']._serialized_options = b'\202\343\n\034\212\343\n\030cognito:access-key:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\016\"\014/access-keys'
  _COGNITO.methods_by_name['DeleteAccessKey']._options = None
  _COGNITO.methods_by_name['DeleteAccessKey']._serialized_options = b'\202\343\n\034\212\343\n\030cognito:access-key:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027*\025/access-keys/{key_id}'
  _COGNITO.methods_by_name['ListAccessKeys']._options = None
  _COGNITO.methods_by_name['ListAccessKeys']._serialized_options = b'\202\343\n\033\212\343\n\027cognito:access-key:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/access-keys'
  _COGNITO.methods_by_name['CreateUser']._options = None
  _COGNITO.methods_by_name['CreateUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\010\"\006/users'
  _COGNITO.methods_by_name['VerifyEmail']._options = None
  _COGNITO.methods_by_name['VerifyEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002\031\"\027/users/{user_id}/verify'
  _COGNITO.methods_by_name['ResendEmailVerification']._options = None
  _COGNITO.methods_by_name['ResendEmailVerification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002!\"\037/self/email/resend-verification'
  _COGNITO.methods_by_name['UpdateEmail']._options = None
  _COGNITO.methods_by_name['UpdateEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002\r\"\013/self/email'
  _COGNITO.methods_by_name['UpdateProfile']._options = None
  _COGNITO.methods_by_name['UpdateProfile']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\007\"\005/self'
  _COGNITO.methods_by_name['UpdatePicture']._options = None
  _COGNITO.methods_by_name['UpdatePicture']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\017\"\r/self/picture'
  _COGNITO.methods_by_name['UpdatePassword']._options = None
  _COGNITO.methods_by_name['UpdatePassword']._serialized_options = b'\202\343\n\022\212\343\n\016password_grant\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\020\"\016/self/password'
  _COGNITO.methods_by_name['IntrospectUser']._options = None
  _COGNITO.methods_by_name['IntrospectUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\007\022\005/self'
  _COGNITO.methods_by_name['DescribeUser']._options = None
  _COGNITO.methods_by_name['DescribeUser']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\014\365\342\n\000\000HC\370\342\n\364\003\202\323\344\223\002\022\022\020/users/{user_id}'
  _COGNITO.methods_by_name['ListUsers']._options = None
  _COGNITO.methods_by_name['ListUsers']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\013\365\342\n\000\000pA\370\342\nd\202\323\344\223\002\010\022\006/users'
  _COGNITO.methods_by_name['IntrospectQuota']._options = None
  _COGNITO.methods_by_name['IntrospectQuota']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/self/quota'
  _COGNITO.methods_by_name['IntrospectRoles']._options = None
  _COGNITO.methods_by_name['IntrospectRoles']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/self/roles'
  _COGNITO.methods_by_name['ListRoles']._options = None
  _COGNITO.methods_by_name['ListRoles']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:role:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\030\022\026/users/{user_id}/roles'
  _COGNITO.methods_by_name['UpdateRoles']._options = None
  _COGNITO.methods_by_name['UpdateRoles']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:role:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\030\032\026/users/{user_id}/roles'
  _COGNITO.methods_by_name['StartRecovery']._options = None
  _COGNITO.methods_by_name['StartRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\323\344\223\002\020\"\016/self/recovery'
  _COGNITO.methods_by_name['CompleteRecovery']._options = None
  _COGNITO.methods_by_name['CompleteRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\032\"\030/users/{user_id}/recover'
  _COGNITO.methods_by_name['SelfDestruct']._options = None
  _COGNITO.methods_by_name['SelfDestruct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\007*\005/self'
  _CREATETOKENINPUT._serialized_start=304
  _CREATETOKENINPUT._serialized_end=636
  _CREATETOKENINPUT_GRANTTYPE._serialized_start=541
  _CREATETOKENINPUT_GRANTTYPE._serialized_end=636
  _CREATETOKENOUTPUT._serialized_start=639
  _CREATETOKENOUTPUT._serialized_end=809
  _INTROSPECTTOKENINPUT._serialized_start=811
  _INTROSPECTTOKENINPUT._serialized_end=848
  _INTROSPECTTOKENOUTPUT._serialized_start=851
  _INTROSPECTTOKENOUTPUT._serialized_end=1104
  _CREATEAUTHORIZATIONINPUT._serialized_start=1107
  _CREATEAUTHORIZATIONINPUT._serialized_end=1282
  _CREATEAUTHORIZATIONOUTPUT._serialized_start=1284
  _CREATEAUTHORIZATIONOUTPUT._serialized_end=1361
  _INTROSPECTQUOTAINPUT._serialized_start=1363
  _INTROSPECTQUOTAINPUT._serialized_end=1385
  _INTROSPECTQUOTAOUTPUT._serialized_start=1388
  _INTROSPECTQUOTAOUTPUT._serialized_end=1621
  _INTROSPECTUSERINPUT._serialized_start=1623
  _INTROSPECTUSERINPUT._serialized_end=1644
  _INTROSPECTUSEROUTPUT._serialized_start=1646
  _INTROSPECTUSEROUTPUT._serialized_end=1704
  _DESCRIBEUSERINPUT._serialized_start=1706
  _DESCRIBEUSERINPUT._serialized_end=1742
  _DESCRIBEUSEROUTPUT._serialized_start=1744
  _DESCRIBEUSEROUTPUT._serialized_end=1800
  _LISTUSERSINPUT._serialized_start=1803
  _LISTUSERSINPUT._serialized_end=2013
  _LISTUSERSINPUT_FILTER._serialized_start=1907
  _LISTUSERSINPUT_FILTER._serialized_end=2013
  _LISTUSERSOUTPUT._serialized_start=2015
  _LISTUSERSOUTPUT._serialized_end=2084
  _CREATEUSERINPUT._serialized_start=2087
  _CREATEUSERINPUT._serialized_end=2242
  _CREATEUSEROUTPUT._serialized_start=2244
  _CREATEUSEROUTPUT._serialized_end=2312
  _NOTIFYUSERINPUT._serialized_start=2315
  _NOTIFYUSERINPUT._serialized_end=2487
  _NOTIFYUSERINPUT_PARAMETERSENTRY._serialized_start=2438
  _NOTIFYUSERINPUT_PARAMETERSENTRY._serialized_end=2487
  _NOTIFYUSEROUTPUT._serialized_start=2489
  _NOTIFYUSEROUTPUT._serialized_end=2532
  _VERIFYEMAILINPUT._serialized_start=2534
  _VERIFYEMAILINPUT._serialized_end=2585
  _VERIFYEMAILOUTPUT._serialized_start=2587
  _VERIFYEMAILOUTPUT._serialized_end=2606
  _UPDATEEMAILINPUT._serialized_start=2608
  _UPDATEEMAILINPUT._serialized_end=2641
  _UPDATEEMAILOUTPUT._serialized_start=2643
  _UPDATEEMAILOUTPUT._serialized_end=2695
  _UPDATEPROFILEINPUT._serialized_start=2698
  _UPDATEPROFILEINPUT._serialized_end=3046
  _UPDATEPROFILEINPUT_PATCH._serialized_start=2926
  _UPDATEPROFILEINPUT_PATCH._serialized_end=3046
  _UPDATEPROFILEOUTPUT._serialized_start=3048
  _UPDATEPROFILEOUTPUT._serialized_end=3102
  _UPDATEPICTUREINPUT._serialized_start=3104
  _UPDATEPICTUREINPUT._serialized_end=3206
  _UPDATEPICTUREOUTPUT._serialized_start=3208
  _UPDATEPICTUREOUTPUT._serialized_end=3229
  _UPDATEPASSWORDINPUT._serialized_start=3231
  _UPDATEPASSWORDINPUT._serialized_end=3300
  _UPDATEPASSWORDOUTPUT._serialized_start=3302
  _UPDATEPASSWORDOUTPUT._serialized_end=3324
  _RESENDEMAILVERIFICATIONINPUT._serialized_start=3326
  _RESENDEMAILVERIFICATIONINPUT._serialized_end=3356
  _RESENDEMAILVERIFICATIONOUTPUT._serialized_start=3358
  _RESENDEMAILVERIFICATIONOUTPUT._serialized_end=3422
  _STARTRECOVERYINPUT._serialized_start=3424
  _STARTRECOVERYINPUT._serialized_end=3492
  _STARTRECOVERYOUTPUT._serialized_start=3494
  _STARTRECOVERYOUTPUT._serialized_end=3544
  _COMPLETERECOVERINPUT._serialized_start=3546
  _COMPLETERECOVERINPUT._serialized_end=3619
  _COMPLETERECOVEROUTPUT._serialized_start=3621
  _COMPLETERECOVEROUTPUT._serialized_end=3644
  _INTROSPECTROLESINPUT._serialized_start=3646
  _INTROSPECTROLESINPUT._serialized_end=3668
  _INTROSPECTROLESOUTPUT._serialized_start=3670
  _INTROSPECTROLESOUTPUT._serialized_end=3708
  _LISTROLESINPUT._serialized_start=3710
  _LISTROLESINPUT._serialized_end=3743
  _LISTROLESOUTPUT._serialized_start=3745
  _LISTROLESOUTPUT._serialized_end=3777
  _UPDATEROLESINPUT._serialized_start=3779
  _UPDATEROLESINPUT._serialized_end=3829
  _UPDATEROLESOUTPUT._serialized_start=3831
  _UPDATEROLESOUTPUT._serialized_end=3850
  _SELFDESTRUCTINPUT._serialized_start=3852
  _SELFDESTRUCTINPUT._serialized_end=3871
  _SELFDESTRUCTOUTPUT._serialized_start=3873
  _SELFDESTRUCTOUTPUT._serialized_end=3940
  _REVOKETOKENINPUT._serialized_start=3942
  _REVOKETOKENINPUT._serialized_end=3975
  _REVOKETOKENOUTPUT._serialized_start=3977
  _REVOKETOKENOUTPUT._serialized_end=3996
  _SIGNININPUT._serialized_start=3998
  _SIGNININPUT._serialized_end=4047
  _SIGNINOUTPUT._serialized_start=4049
  _SIGNINOUTPUT._serialized_end=4099
  _SIGNOUTINPUT._serialized_start=4101
  _SIGNOUTINPUT._serialized_end=4135
  _SIGNOUTOUTPUT._serialized_start=4137
  _SIGNOUTOUTPUT._serialized_end=4152
  _CREATEACCESSKEYINPUT._serialized_start=4154
  _CREATEACCESSKEYINPUT._serialized_end=4225
  _CREATEACCESSKEYOUTPUT._serialized_start=4227
  _CREATEACCESSKEYOUTPUT._serialized_end=4282
  _DELETEACCESSKEYINPUT._serialized_start=4284
  _DELETEACCESSKEYINPUT._serialized_end=4322
  _DELETEACCESSKEYOUTPUT._serialized_start=4324
  _DELETEACCESSKEYOUTPUT._serialized_end=4347
  _LISTACCESSKEYSINPUT._serialized_start=4349
  _LISTACCESSKEYSINPUT._serialized_end=4400
  _LISTACCESSKEYSOUTPUT._serialized_start=4402
  _LISTACCESSKEYSOUTPUT._serialized_end=4481
  _COGNITO._serialized_start=4484
  _COGNITO._serialized_end=7747
# @@protoc_insertion_point(module_scope)
