# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/solution_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import solution_pb2 as eolymp_dot_atlas_dot_solution__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/atlas/solution_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/atlas/solution.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\xf1\x03\n\x12ListSolutionsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.atlas.ListSolutionsInput.Filter\x12\x37\n\x04sort\x18\x32 \x01(\x0e\x32).eolymp.atlas.ListSolutionsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xd8\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x04name\x18\x0c \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x31\n\x07runtime\x18\r \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x1e\n\x08Sortable\x12\x08\n\x04NAME\x10\x00\x12\x08\n\x04TYPE\x10\x01\"K\n\x13ListSolutionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.atlas.Solution\"Q\n\x15\x44\x65scribeSolutionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x13\n\x0bsolution_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"B\n\x16\x44\x65scribeSolutionOutput\x12(\n\x08solution\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"S\n\x13\x43reateSolutionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12(\n\x08solution\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"+\n\x14\x43reateSolutionOutput\x12\x13\n\x0bsolution_id\x18\x01 \x01(\t\"\xeb\x01\n\x13UpdateSolutionInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.atlas.UpdateSolutionInput.Patch\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x13\n\x0bsolution_id\x18\x03 \x01(\t\x12(\n\x08solution\x18\x04 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"I\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x08\n\x04TYPE\x10\x02\x12\x0b\n\x07RUNTIME\x10\x03\x12\n\n\x06SOURCE\x10\x04\x12\n\n\x06SECRET\x10\x05\"\x16\n\x14UpdateSolutionOutput\">\n\x13\x44\x65leteSolutionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x13\n\x0bsolution_id\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteSolutionOutput2\xb4\x06\n\x0fSolutionService\x12\x95\x01\n\x0e\x43reateSolution\x12!.eolymp.atlas.CreateSolutionInput\x1a\".eolymp.atlas.CreateSolutionOutput\"<\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0c\x1a\n/solutions\x12\xa3\x01\n\x0eUpdateSolution\x12!.eolymp.atlas.UpdateSolutionInput\x1a\".eolymp.atlas.UpdateSolutionOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a\x1a\x18/solutions/{solution_id}\x12\xa3\x01\n\x0e\x44\x65leteSolution\x12!.eolymp.atlas.DeleteSolutionInput\x1a\".eolymp.atlas.DeleteSolutionOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a*\x18/solutions/{solution_id}\x12\xa8\x01\n\x10\x44\x65scribeSolution\x12#.eolymp.atlas.DescribeSolutionInput\x1a$.eolymp.atlas.DescribeSolutionOutput\"I\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1a\x12\x18/solutions/{solution_id}\x12\x91\x01\n\rListSolutions\x12 .eolymp.atlas.ListSolutionsInput\x1a!.eolymp.atlas.ListSolutionsOutput\";\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/solutionsB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.solution_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SOLUTIONSERVICE.methods_by_name['CreateSolution']._options = None
  _SOLUTIONSERVICE.methods_by_name['CreateSolution']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\014\032\n/solutions'
  _SOLUTIONSERVICE.methods_by_name['UpdateSolution']._options = None
  _SOLUTIONSERVICE.methods_by_name['UpdateSolution']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\032\032\030/solutions/{solution_id}'
  _SOLUTIONSERVICE.methods_by_name['DeleteSolution']._options = None
  _SOLUTIONSERVICE.methods_by_name['DeleteSolution']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\032*\030/solutions/{solution_id}'
  _SOLUTIONSERVICE.methods_by_name['DescribeSolution']._options = None
  _SOLUTIONSERVICE.methods_by_name['DescribeSolution']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\032\022\030/solutions/{solution_id}'
  _SOLUTIONSERVICE.methods_by_name['ListSolutions']._options = None
  _SOLUTIONSERVICE.methods_by_name['ListSolutions']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/solutions'
  _LISTSOLUTIONSINPUT._serialized_start=251
  _LISTSOLUTIONSINPUT._serialized_end=748
  _LISTSOLUTIONSINPUT_FILTER._serialized_start=500
  _LISTSOLUTIONSINPUT_FILTER._serialized_end=716
  _LISTSOLUTIONSINPUT_SORTABLE._serialized_start=718
  _LISTSOLUTIONSINPUT_SORTABLE._serialized_end=748
  _LISTSOLUTIONSOUTPUT._serialized_start=750
  _LISTSOLUTIONSOUTPUT._serialized_end=825
  _DESCRIBESOLUTIONINPUT._serialized_start=827
  _DESCRIBESOLUTIONINPUT._serialized_end=908
  _DESCRIBESOLUTIONOUTPUT._serialized_start=910
  _DESCRIBESOLUTIONOUTPUT._serialized_end=976
  _CREATESOLUTIONINPUT._serialized_start=978
  _CREATESOLUTIONINPUT._serialized_end=1061
  _CREATESOLUTIONOUTPUT._serialized_start=1063
  _CREATESOLUTIONOUTPUT._serialized_end=1106
  _UPDATESOLUTIONINPUT._serialized_start=1109
  _UPDATESOLUTIONINPUT._serialized_end=1344
  _UPDATESOLUTIONINPUT_PATCH._serialized_start=1271
  _UPDATESOLUTIONINPUT_PATCH._serialized_end=1344
  _UPDATESOLUTIONOUTPUT._serialized_start=1346
  _UPDATESOLUTIONOUTPUT._serialized_end=1368
  _DELETESOLUTIONINPUT._serialized_start=1370
  _DELETESOLUTIONINPUT._serialized_end=1432
  _DELETESOLUTIONOUTPUT._serialized_start=1434
  _DELETESOLUTIONOUTPUT._serialized_end=1456
  _SOLUTIONSERVICE._serialized_start=1459
  _SOLUTIONSERVICE._serialized_end=2279
# @@protoc_insertion_point(module_scope)
