# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/mailing/email_subscription_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.mailing import email_type_pb2 as eolymp_dot_mailing_dot_email__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/eolymp/mailing/email_subscription_service.proto\x12\x0e\x65olymp.mailing\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1f\x65olymp/mailing/email_type.proto\"/\n\x1e\x44\x65scribeEmailSubscriptionInput\x12\r\n\x05token\x18\x01 \x01(\t\"S\n\x1f\x44\x65scribeEmailSubscriptionOutput\x12\x30\n\rsubscriptions\x18\x01 \x03(\x0e\x32\x19.eolymp.mailing.EmailType\"_\n\x1cUpdateEmailSubscriptionInput\x12\r\n\x05token\x18\x01 \x01(\t\x12\x30\n\rsubscriptions\x18\x02 \x03(\x0e\x32\x19.eolymp.mailing.EmailType\"\x1f\n\x1dUpdateEmailSubscriptionOutput2\xea\x02\n\x18\x45mailSubscriptionService\x12\xa8\x01\n\x19\x44\x65scribeEmailSubscription\x12..eolymp.mailing.DescribeEmailSubscriptionInput\x1a/.eolymp.mailing.DescribeEmailSubscriptionOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x15\x12\x13/email-subscription\x12\xa2\x01\n\x17UpdateEmailSubscription\x12,.eolymp.mailing.UpdateEmailSubscriptionInput\x1a-.eolymp.mailing.UpdateEmailSubscriptionOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x15\"\x13/email-subscriptionB1Z/github.com/eolymp/go-sdk/eolymp/mailing;mailingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.mailing.email_subscription_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/mailing;mailing'
  _EMAILSUBSCRIPTIONSERVICE.methods_by_name['DescribeEmailSubscription']._options = None
  _EMAILSUBSCRIPTIONSERVICE.methods_by_name['DescribeEmailSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\025\022\023/email-subscription'
  _EMAILSUBSCRIPTIONSERVICE.methods_by_name['UpdateEmailSubscription']._options = None
  _EMAILSUBSCRIPTIONSERVICE.methods_by_name['UpdateEmailSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\025\"\023/email-subscription'
  _DESCRIBEEMAILSUBSCRIPTIONINPUT._serialized_start=167
  _DESCRIBEEMAILSUBSCRIPTIONINPUT._serialized_end=214
  _DESCRIBEEMAILSUBSCRIPTIONOUTPUT._serialized_start=216
  _DESCRIBEEMAILSUBSCRIPTIONOUTPUT._serialized_end=299
  _UPDATEEMAILSUBSCRIPTIONINPUT._serialized_start=301
  _UPDATEEMAILSUBSCRIPTIONINPUT._serialized_end=396
  _UPDATEEMAILSUBSCRIPTIONOUTPUT._serialized_start=398
  _UPDATEEMAILSUBSCRIPTIONOUTPUT._serialized_end=429
  _EMAILSUBSCRIPTIONSERVICE._serialized_start=432
  _EMAILSUBSCRIPTIONSERVICE._serialized_end=794
# @@protoc_insertion_point(module_scope)
