# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/module_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import module_pb2 as eolymp_dot_course_dot_module__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/course/module_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/course/module.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\":\n\x11\x43reateModuleInput\x12%\n\x06module\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Module\"\'\n\x12\x43reateModuleOutput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\xe1\x01\n\x11UpdateModuleInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.course.UpdateModuleInput.Patch\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12%\n\x06module\x18\x03 \x01(\x0b\x32\x15.eolymp.course.Module\"[\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\t\n\x05\x45XTRA\x10\x06\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x05\"\x14\n\x12UpdateModuleOutput\"&\n\x11\x44\x65leteModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteModuleOutput\"i\n\x13\x44\x65scribeModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x12\n\nstudent_id\x18\x02 \x01(\t\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Module.Extra\"=\n\x14\x44\x65scribeModuleOutput\x12%\n\x06module\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Module\"\x98\x03\n\x10ListModulesInput\x12\x12\n\nstudent_id\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.course.ListModulesInput.Filter\x12\x32\n\x04sort\x18\x32 \x01(\x0e\x32$.eolymp.course.ListModulesInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Module.Extra\x1ay\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12/\n\x05\x64raft\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12/\n\x05\x65xtra\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"\x11\n\x04Sort\x12\t\n\x05INDEX\x10\x00\"H\n\x11ListModulesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.course.Module\"%\n\x10StartModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x13\n\x11StartModuleOutput\"\xb1\x01\n\x11\x41ssignModuleInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12/\n\x0bstart_after\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\r \x01(\r\"\x14\n\x12\x41ssignModuleOutput\";\n\x13UnassignModuleInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"\x16\n\x14UnassignModuleOutput2\xa0\n\n\rModuleService\x12\x8f\x01\n\x0c\x43reateModule\x12 .eolymp.course.CreateModuleInput\x1a!.eolymp.course.CreateModuleOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\x1a\x08/modules\x12\x9b\x01\n\x0cUpdateModule\x12 .eolymp.course.UpdateModuleInput\x1a!.eolymp.course.UpdateModuleOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16\x1a\x14/modules/{module_id}\x12\x9b\x01\n\x0c\x44\x65leteModule\x12 .eolymp.course.DeleteModuleInput\x1a!.eolymp.course.DeleteModuleOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16*\x14/modules/{module_id}\x12\xa0\x01\n\x0e\x44\x65scribeModule\x12\".eolymp.course.DescribeModuleInput\x1a#.eolymp.course.DescribeModuleOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x12\x14/modules/{module_id}\x12\x8b\x01\n\x0bListModules\x12\x1f.eolymp.course.ListModulesInput\x1a .eolymp.course.ListModulesOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\x12\x08/modules\x12\x9d\x01\n\x0bStartModule\x12\x1f.eolymp.course.StartModuleInput\x1a .eolymp.course.StartModuleOutput\"K\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c\"\x1a/modules/{module_id}/start\x12\xb3\x01\n\x0c\x41ssignModule\x12 .eolymp.course.AssignModuleInput\x1a!.eolymp.course.AssignModuleOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02.\x1a,/modules/{module_id}/assignments/{member_id}\x12\xb9\x01\n\x0eUnassignModule\x12\".eolymp.course.UnassignModuleInput\x1a#.eolymp.course.UnassignModuleOutput\"^\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02.*,/modules/{module_id}/assignments/{member_id}B/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MODULESERVICE.methods_by_name['CreateModule']._options = None
  _MODULESERVICE.methods_by_name['CreateModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\n\032\010/modules'
  _MODULESERVICE.methods_by_name['UpdateModule']._options = None
  _MODULESERVICE.methods_by_name['UpdateModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026\032\024/modules/{module_id}'
  _MODULESERVICE.methods_by_name['DeleteModule']._options = None
  _MODULESERVICE.methods_by_name['DeleteModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026*\024/modules/{module_id}'
  _MODULESERVICE.methods_by_name['DescribeModule']._options = None
  _MODULESERVICE.methods_by_name['DescribeModule']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\026\022\024/modules/{module_id}'
  _MODULESERVICE.methods_by_name['ListModules']._options = None
  _MODULESERVICE.methods_by_name['ListModules']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\n\022\010/modules'
  _MODULESERVICE.methods_by_name['StartModule']._options = None
  _MODULESERVICE.methods_by_name['StartModule']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034\"\032/modules/{module_id}/start'
  _MODULESERVICE.methods_by_name['AssignModule']._options = None
  _MODULESERVICE.methods_by_name['AssignModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002.\032,/modules/{module_id}/assignments/{member_id}'
  _MODULESERVICE.methods_by_name['UnassignModule']._options = None
  _MODULESERVICE.methods_by_name['UnassignModule']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002.*,/modules/{module_id}/assignments/{member_id}'
  _CREATEMODULEINPUT._serialized_start=282
  _CREATEMODULEINPUT._serialized_end=340
  _CREATEMODULEOUTPUT._serialized_start=342
  _CREATEMODULEOUTPUT._serialized_end=381
  _UPDATEMODULEINPUT._serialized_start=384
  _UPDATEMODULEINPUT._serialized_end=609
  _UPDATEMODULEINPUT_PATCH._serialized_start=518
  _UPDATEMODULEINPUT_PATCH._serialized_end=609
  _UPDATEMODULEOUTPUT._serialized_start=611
  _UPDATEMODULEOUTPUT._serialized_end=631
  _DELETEMODULEINPUT._serialized_start=633
  _DELETEMODULEINPUT._serialized_end=671
  _DELETEMODULEOUTPUT._serialized_start=673
  _DELETEMODULEOUTPUT._serialized_end=693
  _DESCRIBEMODULEINPUT._serialized_start=695
  _DESCRIBEMODULEINPUT._serialized_end=800
  _DESCRIBEMODULEOUTPUT._serialized_start=802
  _DESCRIBEMODULEOUTPUT._serialized_end=863
  _LISTMODULESINPUT._serialized_start=866
  _LISTMODULESINPUT._serialized_end=1274
  _LISTMODULESINPUT_FILTER._serialized_start=1134
  _LISTMODULESINPUT_FILTER._serialized_end=1255
  _LISTMODULESINPUT_SORT._serialized_start=1257
  _LISTMODULESINPUT_SORT._serialized_end=1274
  _LISTMODULESOUTPUT._serialized_start=1276
  _LISTMODULESOUTPUT._serialized_end=1348
  _STARTMODULEINPUT._serialized_start=1350
  _STARTMODULEINPUT._serialized_end=1387
  _STARTMODULEOUTPUT._serialized_start=1389
  _STARTMODULEOUTPUT._serialized_end=1408
  _ASSIGNMODULEINPUT._serialized_start=1411
  _ASSIGNMODULEINPUT._serialized_end=1588
  _ASSIGNMODULEOUTPUT._serialized_start=1590
  _ASSIGNMODULEOUTPUT._serialized_end=1610
  _UNASSIGNMODULEINPUT._serialized_start=1612
  _UNASSIGNMODULEINPUT._serialized_end=1671
  _UNASSIGNMODULEOUTPUT._serialized_start=1673
  _UNASSIGNMODULEOUTPUT._serialized_end=1695
  _MODULESERVICE._serialized_start=1698
  _MODULESERVICE._serialized_end=3010
# @@protoc_insertion_point(module_scope)
